from typing import Iterator
from typing import List
from typing import overload
import ghidra.generic.util.datastruct
import ghidra.generic.util.datastruct.ValueSortedMap
import java.lang
import java.util
import java.util.function


class ValueSortedMap(object):
    """
    A map that is sorted by value.
 
 
     This is an extension of Map where entries are sorted by value, rather than by key. Such a
     map may be useful as a priority queue where the cost of an entry may change over time. As such,
     the collections returned by #entrySet(), #keySet(), and #values() all
     extend Deque. The order of the entries will be updated on any call to
     Map#put(Object, Object), or a call to Collection#add(Object) on the entry set.
     Additionally, if the values are mutable objects, whose order may change, there is an
     #update(Object) method, which notifies the map that the given key may need to be
     repositioned. The associated collections also extend the List interface, providing fairly
     efficient implementations of List#get(int) and List#indexOf(Object). Sequential
     access is best performed via Collection#iterator(), since this will use a linked list.
    """






    class LesserList(java.lang.Iterable, object):






        def __iter__(self): ...

        def contains(self, __a0: object) -> bool: ...

        def equals(self, __a0: object) -> bool: ...

        def forEach(self, __a0: java.util.function.Consumer) -> None: ...

        def get(self, __a0: int) -> object: ...

        def getClass(self) -> java.lang.Class: ...

        def hashCode(self) -> int: ...

        def indexOf(self, __a0: object) -> int: ...

        def isEmpty(self) -> bool: ...

        def iterator(self) -> java.util.Iterator: ...

        def listIterator(self, __a0: int) -> java.util.ListIterator: ...

        def notify(self) -> None: ...

        def notifyAll(self) -> None: ...

        def poll(self) -> object: ...

        def remove(self, __a0: object) -> bool: ...

        def removeAll(self, __a0: java.util.Collection) -> bool: ...

        def size(self) -> int: ...

        def spliterator(self) -> java.util.Spliterator: ...

        def toList(self) -> List[object]: ...

        def toString(self) -> unicode: ...

        @overload
        def wait(self) -> None: ...

        @overload
        def wait(self, __a0: long) -> None: ...

        @overload
        def wait(self, __a0: long, __a1: int) -> None: ...

        @property
        def empty(self) -> bool: ...




    class ValueSortedMapKeyList(ghidra.generic.util.datastruct.ValueSortedMap.LesserList, object):






        def __iter__(self): ...

        def contains(self, __a0: object) -> bool: ...

        def equals(self, __a0: object) -> bool: ...

        def forEach(self, __a0: java.util.function.Consumer) -> None: ...

        def get(self, __a0: int) -> object: ...

        def getClass(self) -> java.lang.Class: ...

        def hashCode(self) -> int: ...

        def indexOf(self, __a0: object) -> int: ...

        def isEmpty(self) -> bool: ...

        def iterator(self) -> java.util.Iterator: ...

        def listIterator(self, __a0: int) -> java.util.ListIterator: ...

        def notify(self) -> None: ...

        def notifyAll(self) -> None: ...

        def poll(self) -> object: ...

        def remove(self, __a0: object) -> bool: ...

        def removeAll(self, __a0: java.util.Collection) -> bool: ...

        def size(self) -> int: ...

        def spliterator(self) -> java.util.Spliterator: ...

        def toList(self) -> List[object]: ...

        def toString(self) -> unicode: ...

        @overload
        def wait(self) -> None: ...

        @overload
        def wait(self, __a0: long) -> None: ...

        @overload
        def wait(self, __a0: long, __a1: int) -> None: ...

        @property
        def empty(self) -> bool: ...




    class ValueSortedMapEntryList(ghidra.generic.util.datastruct.ValueSortedMap.LesserList, object):






        def __iter__(self): ...

        def contains(self, __a0: object) -> bool: ...

        def equals(self, __a0: object) -> bool: ...

        def forEach(self, __a0: java.util.function.Consumer) -> None: ...

        def get(self, __a0: int) -> object: ...

        def getClass(self) -> java.lang.Class: ...

        def hashCode(self) -> int: ...

        def indexOf(self, __a0: object) -> int: ...

        def isEmpty(self) -> bool: ...

        def iterator(self) -> java.util.Iterator: ...

        def listIterator(self, __a0: int) -> java.util.ListIterator: ...

        def notify(self) -> None: ...

        def notifyAll(self) -> None: ...

        def poll(self) -> object: ...

        def remove(self, __a0: object) -> bool: ...

        def removeAll(self, __a0: java.util.Collection) -> bool: ...

        def size(self) -> int: ...

        def spliterator(self) -> java.util.Spliterator: ...

        def toList(self) -> List[object]: ...

        def toString(self) -> unicode: ...

        @overload
        def wait(self) -> None: ...

        @overload
        def wait(self, __a0: long) -> None: ...

        @overload
        def wait(self, __a0: long, __a1: int) -> None: ...

        @property
        def empty(self) -> bool: ...





    def ceilingEntryByValue(self, __a0: object) -> java.util.Map.Entry: ...

    def clear(self) -> None: ...

    def containsKey(self, key: object) -> bool: ...

    def containsValue(self, value: object) -> bool: ...

    def entrySet(self) -> ghidra.generic.util.datastruct.ValueSortedMap.ValueSortedMapEntryList: ...

    def equals(self, __a0: object) -> bool: ...

    def floorEntryByValue(self, __a0: object) -> java.util.Map.Entry: ...

    def get(self, key: object) -> V: ...

    def getClass(self) -> java.lang.Class: ...

    def hashCode(self) -> int: ...

    def headMapByValue(self, __a0: object, __a1: bool) -> ghidra.generic.util.datastruct.ValueSortedMap: ...

    def higherEntryByValue(self, __a0: object) -> java.util.Map.Entry: ...

    def isEmpty(self) -> bool: ...

    def keySet(self) -> ghidra.generic.util.datastruct.ValueSortedMap.ValueSortedMapKeyList: ...

    def lowerEntryByValue(self, __a0: object) -> java.util.Map.Entry: ...

    def notify(self) -> None: ...

    def notifyAll(self) -> None: ...

    def put(self, __a0: object, __a1: object) -> object: ...

    def remove(self, __a0: object) -> object: ...

    def size(self) -> int: ...

    def subMapByValue(self, __a0: object, __a1: bool, __a2: object, __a3: bool) -> ghidra.generic.util.datastruct.ValueSortedMap: ...

    def tailMapByValue(self, __a0: object, __a1: bool) -> ghidra.generic.util.datastruct.ValueSortedMap: ...

    def toString(self) -> unicode: ...

    def update(self, __a0: object) -> bool: ...

    def values(self) -> ghidra.generic.util.datastruct.SortedList: ...

    @overload
    def wait(self) -> None: ...

    @overload
    def wait(self, __a0: long) -> None: ...

    @overload
    def wait(self, __a0: long, __a1: int) -> None: ...

    @property
    def empty(self) -> bool: ...